#!/bin/bash
#
# MoCha: Molecular Characterization
#
# Configuration script: compile the program and download and process the STRING database files
#
# Copyright (C) 2016 Jennifer Hammelman and Daniel Lobo
#               2020 Lobo Lab - https://lobolab.umbc.edu
#
# Version Apr 2020 - Updated to use String v11.
#
# License: GNU GENERAL PUBLIC LICENSE, Version 3

VERSION="v11.0"
LINKS="protein.links.detailed."$VERSION".txt"
PROTEINS="all_organisms.name_2_string.tsv"
ORGANISMS="species."$VERSION".txt"
STRINGDIR="./stringdb"


echo "##### Configuring program files... (this process may take a few hours, depending on your Internet connection) #####"
  
# compile programs
if [ ! -d "./bin" ]; then
  echo "##### Compiling programs... #####"
  make
fi

# download and process String DBs
if [ ! -d $STRINGDIR ]; then
  mkdir $STRINGDIR
    
  echo "##### Downloading STRING DBs... #####"
  wget -P $STRINGDIR https://stringdb-static.org/download/$LINKS.gz
  wget -P $STRINGDIR https://string-db.org/mapping_files/STRING_display_names/$PROTEINS.gz
  wget -P $STRINGDIR https://stringdb-static.org/download/$ORGANISMS
  
  echo "##### Extracting STRING DBs... #####"
  gzip -v -d $STRINGDIR/$LINKS.gz
  gzip -v -d $STRINGDIR/$PROTEINS.gz
  
  echo "##### Renaming files... #####"
  mv $STRINGDIR/$LINKS $STRINGDIR/links 
  mv $STRINGDIR/$PROTEINS $STRINGDIR/proteins
  mv $STRINGDIR/$ORGANISMS $STRINGDIR/organisms

  echo "##### Sorting STRING DBs... #####"
  export LC_ALL=C
  sort -n $STRINGDIR/links -o $STRINGDIR/links
  mv $STRINGDIR/links $STRINGDIR/links.sorted
  
  awk '{sub(/^[0-9]+[.]/, "", $3); print $1"\t"$3"\t"$2}' $STRINGDIR/proteins | uniq > $STRINGDIR/proteins.cut
  rm -f $STRINGDIR/proteins
  sort -n $STRINGDIR/proteins.cut -o $STRINGDIR/proteins.sorted
  sort -t$'\t' -k1,1n -k3 --ignore-case $STRINGDIR/proteins.cut -o $STRINGDIR/proteins.sorted3
  rm -f $STRINGDIR/proteins.cut
  
  echo "##### Creating offsets... #####"
  ./bin/calcoffsets $STRINGDIR/links.sorted $STRINGDIR/links.sorted.offsets
  ./bin/calcoffsets $STRINGDIR/proteins.sorted $STRINGDIR/proteins.sorted.offsets
  ./bin/calcoffsets $STRINGDIR/proteins.sorted3 $STRINGDIR/proteins.sorted3.offsets
  ./bin/calcoffsets $STRINGDIR/organisms $STRINGDIR/organisms.offsets
fi

echo "##### Configuration done. Enjoy the program! #####"
