/* calcoffsets.cpp
**
** MoCha: Molecular Characterization
**
** Calculate and save the line offsets of an input text file.
**
** Copyright (C) 2016 Jennifer Hammelman and Daniel Lobo
**               2020 Lobo Lab - https://lobolab.umbc.edu
**
** Version Apr 2020 - Updated to use String v11.
**
** License: GNU GENERAL PUBLIC LICENSE, Version 3
*/

#include <cstdlib>
#include <cstdio>
#include <iostream>

// Output the usage instructions.
void printUsage() {
  std::cerr << "Usage: calcoffsets [-h] infile outfile" << std::endl;
}

// Check that the arguments passed are correct.
void checkArgs(int argc) {
  if (argc != 3) {
    printUsage();
    exit(1);
  }
}

// Open a file.
FILE *openFile(const char *fileName, const char *mode) {
  FILE *file = fopen(fileName, mode);
  if (file == NULL) {
    std::cerr << "Error opening file: " << fileName << std::endl;
    printUsage();
    exit(1);
  }

  return file;
}

// Main program
int main(int argc, char **argv) {
  checkArgs(argc);

  FILE *inputFile = openFile(argv[1], "r");
  FILE *outputFile = openFile(argv[2], "w");
    
  long pos = 0;
  int c = fgetc(inputFile);
  while(c != EOF) {
    pos++;
    if (c == '\n') {
      fwrite(&pos, sizeof(long), 1, outputFile);
    }
    c = fgetc(inputFile);
  }
  
  fclose(outputFile);
  fclose(inputFile);

  return 0;
}
